---
title: First post
date: 2025-03-12 11:47:11
lastUpdated: 2025-03-12 11:47:11
---

### Hello World!

If you are reading this, you arrived here in the very early days of development.

You can check the [Documentation](/welcome) and the [API Reference](/api) for more information.

Follow the project on [GitHub](https://github.com/vista-art/fragmentcolor) to stay tuned on the latest updates.
